@@ -3,7 +3,7 @@ from qm_spider import *
 
 
 class Send_Mail:
-    def __init__(self, subject, mail_text, file_path, send_user, send_userpwd, receivers=('ctrlf4@yeah.net'), cc=()):
+    def __init__(self, subject, mail_text, send_user, send_userpwd, receivers=('ctrlf4@yeah.net'), file_path='', from_user='', cc=()):
         self.subject = subject
         self.mail_text = mail_text
         self.file_path = file_path
@@ -11,14 +11,23 @@ class Send_Mail:
         self.send_user = send_user
         self.send_userpwd = send_userpwd
         self.cc = cc
+        self.from_user = from_user
 
     def send_qm_mail(self):
-        self.mail_content = {
-            'Subject': self.subject,  # 邮件标题
-            'From': self.subject, # 来自XX
-            'Content_text': self.mail_text,  # 邮件正文
-            'Attachments': self.file_path  # 邮件附件
-        }
+        if len(self.from_user) > 0:
+            self.mail_content = {
+                'Subject': self.subject,  # 邮件标题
+                'From': self.from_user, # 来自XX
+                'Content_text': self.mail_text,  # 邮件正文
+                'Attachments': self.file_path  # 邮件附件
+            }
+        else:
+            self.mail_content = {
+                'Subject': self.subject,  # 邮件标题
+                'From': self.subject, # 来自XX
+                'Content_text': self.mail_text,  # 邮件正文
+                'Attachments': self.file_path  # 邮件附件
+            }
 
         if '@qimai.cn' in self.send_user:
             server = zmail.server(self.send_user, self.send_userpwd, smtp_host='smtp.exmail.qq.com', smtp_port=465)
