@@ -10,7 +10,7 @@ from snapshot_selenium import snapshot
 
 # 画图基础通用参数；
 class Pyecharts_Var:
-    def __init__(self, title, x_value, y_name, y_value, *args, subtitle='', is_symbol_show=False, line_width=1, is_show=False, color_list=('#00b088', '#f76b61', '#ffb55d', '#8470ff', '#00a2ff', '#ffe400', '#11d2c2', '#c263f9')):
+    def __init__(self, title, x_value, y_name, y_value, *args, subtitle='', is_symbol_show=False, line_width=2, is_show=False, color_list=['#00b088', '#f76b61', '#ffb55d', '#8470ff', '#00a2ff', '#ffe400', '#11d2c2', '#c263f9']):
         self.subtitle = subtitle
         self.is_symbol_show = is_symbol_show
         self.line_width = line_width
@@ -28,7 +28,7 @@ class Pyecharts_Var:
 # 折线图、面积图；
 class Line_Py(Pyecharts_Var):
     def __init__(self, title, x_value, y_name, y_value, *args):
-        Pyecharts_Var.__init__(self, title, x_value, y_name, y_value)
+        Pyecharts_Var.__init__(self, title, x_value, y_name, y_value, *args)
 
     def line_render_air(self):
         c = Line()
@@ -43,10 +43,10 @@ class Line_Py(Pyecharts_Var):
         c.set_global_opts(
             title_opts=opts.TitleOpts(title=self.title, subtitle=self.subtitle),
         )
-        for agr_data in self.args:
+        for num in range(len(self.args[0])):
             c.add_yaxis(
-                series_name = agr_data[0],
-                y_axis = agr_data[1],
+                series_name = self.args[0][num],
+                y_axis = self.args[1][num],
                 is_symbol_show=self.is_symbol_show,
                 linestyle_opts=opts.LineStyleOpts(width=self.line_width),
                 label_opts=opts.LabelOpts(is_show=self.is_show)
@@ -58,12 +58,12 @@ class Line_Py(Pyecharts_Var):
         c = Line(init_opts=opts.InitOpts(width="1200px", height="400px"))
         c.add_xaxis(self.x_value)
         c.add_yaxis(
-            series_name=self.x_value,
+            series_name=self.y_name,
+            y_axis=self.y_value,
             is_symbol_show=self.is_symbol_show,  # 线上不用点标记
             color=self.color_list[0],
             linestyle_opts=opts.LineStyleOpts(width=self.line_width),  # 线条加粗
-            y_axis=self.y_value,
-            label_opts=opts.LabelOpts(is_show=self.is_show),
+            label_opts=opts.LabelOpts(is_show=self.is_show)
         )
         c.set_global_opts(
             title_opts=opts.TitleOpts(
@@ -162,15 +162,20 @@ class Line_Py(Pyecharts_Var):
             #             ]
         )
         # 插入其他y线条；
-        for num, agr_data in enumerate(self.args):
-            c.add_yaxis(
-                series_name=agr_data[0],
-                is_symbol_show=self.is_symbol_show,  # 线上不用点标记
-                color=self.color_list[num+1],
-                linestyle_opts=opts.LineStyleOpts(width=self.line_width),  # 线条加粗
-                y_axis=agr_data[1],
-                label_opts=opts.LabelOpts(is_show=self.is_show),
-            )
+        if len(self.args) > 0:
+            for num in range(len(self.args[0])):
+                if num+1 > len(self.color_list)-1:
+                    color_str = ''
+                else:
+                    color_str = self.color_list[num+1]
+                c.add_yaxis(
+                    series_name=self.args[0][num],
+                    y_axis=self.args[1][num],
+                    is_symbol_show=self.is_symbol_show,  # 线上不用点标记
+                    color=color_str,
+                    linestyle_opts=opts.LineStyleOpts(width=self.line_width),  # 线条加粗
+                    label_opts=opts.LabelOpts(is_show=self.is_show),
+                )
         self.c_render = c
         return c
 
